@@ -16,7 +16,7 @@
  *
  * for 0.94: support alt_is_meta
  */
-#include <lct/cline.h>
+#include <config.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -31,6 +31,7 @@
 #include <linux/keyboard.h>
 
 #include <lct/ksyms.h>
+#include <lct/local.h>
 #include <lct/utils.h>
 #include <lct/console.h>
 #include <lct/modifiers.h>
@@ -46,6 +47,7 @@
 int verbose;
 
 static int fd;
+char* progname;
 
 int keymap_index[MAX_NR_KEYMAPS];		/* inverse of good_keymap */
 int good_keymap[MAX_NR_KEYMAPS], keymapnr, allocct;
@@ -60,7 +62,7 @@ void get_keymaps(void) {
 	    ke.kb_table = i;
 	    j = ioctl(fd, KDGKBENT, (unsigned long)&ke);
 	    if (j && errno != EINVAL) {
-		fprintf(stderr, _("KDGKBENT at index 0 in table %d: "), i);
+		fprintf(stderr, "KDGKBENT at index 0 in table %d: ", i);
 		perror("");
 		exit (EX_OSERR);
 	    }
@@ -74,12 +76,12 @@ void get_keymaps(void) {
 	    }
 	}
 	if (keymapnr == 0) {
-	    fprintf(stderr, _("%s: cannot find any keymaps?\n"), progname);
+	    fprintf(stderr, "%s: cannot find any keymaps?\n", progname);
 	    exit (EX_NOINPUT);
 	}
 	if (good_keymap[0] != 0) {
 	    fprintf(stderr,
-		    _("%s: plain map not allocated? very strange ...\n"), progname);
+		    "%s: plain map not allocated? very strange ...\n", progname);
 	    /* this is not fatal */
 	}
 }
@@ -87,7 +89,7 @@ void get_keymaps(void) {
 void print_keymaps(void) {
 	int i,m0,m;
 
-	printf(_("keymaps "));
+	printf("keymaps ");
 	for (i=0; i<keymapnr; i++) {
 	    if (i)
 	      printf(",");
@@ -108,7 +110,7 @@ int get_bind(u_char index, u_char table) {
 	ke.kb_index = index;
 	ke.kb_table = table;
 	if (ioctl(fd, KDGKBENT, (unsigned long)&ke)) {
-		fprintf(stderr, _("KDGKBENT at index %d in table %d: "),
+		fprintf(stderr, "KDGKBENT at index %d in table %d: ",
 			index, table);
 		perror("");
 		exit (EX_OSERR);
@@ -154,14 +156,11 @@ char valid_type(int t) {
 }
 
 u_char maximum_val(int t) {
-	struct kbentry ke, ke0;
+	struct kbentry ke;
 	int i;
 
 	ke.kb_index = 0;
 	ke.kb_table = 0;
-	ke.kb_value = K_HOLE; /* useless ? */
-	ke0 = ke;
-	ioctl(fd, KDGKBENT, (unsigned long)&ke0);
 
 	for (i = 0; i < 256; i++) {
 		ke.kb_value = K(t, i);
@@ -169,12 +168,12 @@ u_char maximum_val(int t) {
 			break;
 	}
 	ke.kb_value = K_HOLE;
-	ioctl(fd, KDSKBENT, (unsigned long)&ke0);
+	ioctl(fd, KDSKBENT, (unsigned long)&ke); 	/* superfluous */
 
 	return i - 1;
 }
 
-#define NR_TYPES 15
+#define NR_TYPES 13
 int maxval[NR_TYPES];
 
 #ifdef KDGKBDIACR
@@ -197,7 +196,7 @@ void get_diacs(void) {
 
 	if(!got_diacs && ioctl(fd, KDGKBDIACR, (unsigned long)&kd)) {
 	    perror("");
-	    fprintf(stderr, _("KDGKBDIACR failed\n"));
+	    fprintf(stderr, "KDGKBDIACR failed\n");
 	    exit (EX_OSERR);
 	}
 	got_diacs = 1;
@@ -212,10 +211,7 @@ int nr_of_diacs()
 void dump_diacs()
 {
   unsigned i;
-
-  /* NB. Don't translate since these need to be in the right format
-   * to be loaded back into 'loadkeys'
-   */
+  
   get_diacs();
   for (i = 0; i < kd.kb_cnt; i++) 
     {
@@ -233,27 +229,27 @@ void dump_diacs()
 void show_short_info(void) {
 	int i;
 
-	printf(_("keycode range supported by kernel:           1 - %d\n"),
+	printf("keycode range supported by kernel:           1 - %d\n",
 	       NR_KEYS - 1);
-	printf(_("max number of actions bindable to a key:         %d\n"),
+	printf("max number of actions bindable to a key:         %d\n",
 	       MAX_NR_KEYMAPS);
 	get_keymaps();
-	printf(_("number of keymaps in actual use:                 %d\n"),
+	printf("number of keymaps in actual use:                 %d\n",
 	       keymapnr);
 	if (allocct)
-	  printf(_("of which %d dynamically allocated\n"), allocct);
-	printf(_("ranges of action codes supported by kernel:\n"));
+	  printf("of which %d dynamically allocated\n", allocct);
+	printf("ranges of action codes supported by kernel:\n");
 	for (i = 0; i < NR_TYPES && valid_type(i); i++) {
 	    maxval[i] = maximum_val(i);
 	    printf("	0x%04x - 0x%04x\n", K(i, 0), K(i, maxval[i]));
 	}
-	printf(_("number of function keys supported by kernel: %d\n"),
+	printf("number of function keys supported by kernel: %d\n",
 	       MAX_NR_FUNC);
 
-	printf(_("max nr of compose definitions: %d\n"),
+	printf("max nr of compose definitions: %d\n",
 	       MAX_DIACR);
 #ifdef KDGKBDIACR
-	printf(_("nr of compose definitions in actual use: %d\n"),
+	printf("nr of compose definitions in actual use: %d\n",
 	       nr_of_diacs());
 #endif
 }
@@ -277,7 +273,7 @@ void dump_symbols(void) {
 	int v;
 	char *p;
 
-	printf(_("Symbols recognized by %s:\n(numeric value, symbol)\n\n"), progname);
+	printf("Symbols recognized by %s:\n(numeric value, symbol)\n\n", progname);
 	for (t = 0; t < syms_size; t++) {
 	    if (syms[t].size) {
 		for (v = 0; v < syms[t].size; v++)
@@ -289,11 +285,11 @@ void dump_symbols(void) {
 				printf("0x%04x\tMeta_%s\n", K(t, v), p);
 	    }
 	}
-	printf(_("\nThe following synonyms are recognized:\n\n"));
+	printf("\nThe following synonyms are recognized:\n\n");
 	for (t = 0; t < syn_size; t++)
 	  printf("%-15s for %s\n", synonyms[t].synonym,
 		 synonyms[t].official_name);
-	printf(_("\nRecognized modifier names and their column numbers:\n"));
+	printf("\nRecognized modifier names and their column numbers:\n");
 	for (t = 0; t < sizeof(modifiers)/sizeof(modifiers[0]); t++)
 	  printf("%s\t\t%3d\n", modifiers[t].name, 1 << modifiers[t].bit);
 }
@@ -303,7 +299,7 @@ void print_mod(int x)
   unsigned t;
   
   if (!x)
-    printf(_("plain\t"));
+    printf("plain\t");
   else
     for (t = 0; t < sizeof(modifiers)/sizeof(modifiers[0]); t++)
       if (x & (1 << modifiers[t].bit))
@@ -314,7 +310,7 @@ void print_bind(int bufj, int i, int j, char numeric) {
   if (j)
     printf("\t");
   print_mod(j);
-  printf(_("keycode %3d ="), i);
+  printf("keycode %3d =", i);
   print_keysym(bufj, numeric);
   printf("\n");
 }
@@ -429,7 +425,7 @@ no_shorthands:
 		       && ((typ=KTYP(buf[j])) == KT_LATIN || typ == KT_LETTER)
 		       && KVAL(buf[j]) < 128) {
 			   if (buf[ja] != K(KT_META, KVAL(buf[j])))
-				fprintf(stderr, _("impossible: not meta?\n"));
+				fprintf(stderr, "impossible: not meta?\n");
 			   buf[ja] = K_HOLE;
 			   zapped[ja] = 1;
 		      }
@@ -484,7 +480,7 @@ void dump_funcs() {
 		if (ioctl(fd, KDGKBSENT, (unsigned long)&fbuf)) {
 		    if (errno == EINVAL && i > 0) /* an old kernel */
 		      break;
-		    fprintf(stderr, _("KDGKBSENT at index %d: "), i);
+		    fprintf(stderr, "KDGKBSENT at index %d: ", i);
 		    perror("");
 		    exit (EX_OSERR);
 		}
@@ -507,34 +503,42 @@ void usage()
 {
   struct cs *c;
   
-  printf(_("Usage: %s [options...]\n"), progname);
-  OPTIONS_ARE();
-  OPT("-i --short-info      ", _("display information about keyboard driver"));
-  OPT("-l --long-info       ", _("display above and symbols known to loadkeys"));
-  OPT("-n --numeric         ", _("display keytable in hexadecimal notation"));
-  OPT("-f --full-table      ", _("don't use short-hand notations, one row per keycode"));
-  OPT("-1 --separate-lines  ", _("one line per (modifier,keycode) pair"));
-  OPT("   --funcs-only      ", _("display only the function key strings"));
-  OPT("   --keys-only       ", _("display only key bindings"));
-  OPT("-S --shape=<shape>   ", _("choose output shape, where <shape> is:"));
-  OPT("                     ", _(" 0 = default"));
-  OPT("                     ", _(" 1 = same as --full-table"));
-  OPT("                     ", _(" 2 = same as --separate-lines"));
-  OPT("                     ", _(" 3 = one line per keycode, until 1st hole"));
+  version();
+  
+  fprintf(stderr,
+	  "Usage: %s [options...]\n"
+	  "\n"
+	  "valid options are:\n"
+	  "\n"
+	  "        -h --help            display this help text\n"
+	  "        -i --short-info      display information about keyboard driver\n"
+	  "        -l --long-info       display above and symbols known to loadkeys\n"
+	  "        -n --numeric         display keytable in hexadecimal notation\n"
+	  "        -f --full-table      don't use short-hand notations, one row per keycode\n"
+	  "        -1 --separate-lines  one line per (modifier,keycode) pair\n"
+	  "           --funcs-only      display only the function key strings\n"
+	  "           --keys-only       display only key bindings\n"
+	  "        -S --shape=<shape>   choose output shape, where <shape> is:\n"
+	  "                              0 = default\n"
+	  "                              1 = same as --full-table\n"
+	  "                              2 = same as --separate-lines\n"
+	  "                              3 = one line per keycode, until 1st hole\n"
+	  "%s"
+	  "        -c --charset=<charset-name>\n"
+	  "                          interpret character action codes to be from the\n"
+	  "                          specified character set\n"
+	  "\n"
+	  "available charsets:\n",
+	  progname,
 #ifdef KDGKBDIACR
-  OPT("   --compose-only    ", _("display only compose key combinations"));
+	  "           --compose-only display only compose key combinations\n"
+#else
+	  ""
 #endif
-  OPT("-c --charset=<charset-name>", "");
-  OPT("                     ", _("interpret character action codes to be from the"));
-  OPT("                     ", _("specified character set"));
-
-  OPT("-h --help            ", _("display this help text and exit"));
-  OPT("-V --version         ", _("display version information and exit"));
-
-  printf (_("\navailable charsets:\n"));
+	  );
 
   for (c = charsets; c->charset ; c++)
-    printf("\t%s\n", c->charset);
+    fprintf(stderr, "\t%s\n", c->charset);
 }
 
 int main (int argc, char *argv[]) 
@@ -555,7 +559,6 @@ int main (int argc, char *argv[])
     { "compose-only",no_argument,           NULL, 'd' },
 #endif
     { "verbose",	no_argument,		NULL, 'v' },
-    { "version",        no_argument,            NULL, 'V' },
     { "charset",	required_argument,	NULL, 'c' },
     { NULL,	0, NULL, 0 }
   };
@@ -570,7 +573,7 @@ int main (int argc, char *argv[])
   char diac_only = 0;
 #endif
 
-  miscsetup();
+  progname = strip_path(argv[0]);
   
   while ((c = getopt_long(argc, argv,
 			  short_opts, long_opts, NULL)) != EOF)
@@ -610,9 +613,6 @@ int main (int argc, char *argv[])
 	case 'v':
 	  verbose = 1;
 	  break;
-	case 'V':
-	  version();
-	  exit(0);
 	case 'c':
 	  if ((set_charset(optarg)) != 0)
 	    badusage((char*)NULL);   /* message already printed */
@@ -627,7 +627,7 @@ int main (int argc, char *argv[])
     }
 
   if (optind < argc)
-    badusage(_("no non-option arguments allowed"));
+    badusage("no non-option arguments allowed");
   
   if (-1 == (fd = get_console_fd(NULL)))
     exit (EX_OSERR);
