@@ -3,9 +3,6 @@
  *
  * aeb, 941108
  */
-
-#include <lct/cline.h>
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -13,17 +10,15 @@
 #include <sys/ioctl.h>
 #include <linux/kd.h>
 
+#include <lct/local.h>
 #include <lct/utils.h>
 #include <lct/console.h>
 
+char* progname;
 
-static void usage()
+void usage() 
 {
-  printf(_("Usage: %s\n"
-	   "Print kernel scancode-to-keycode mapping table\n"), progname);
-  OPTIONS_ARE();
-  OPT("-h --help         ", HELPDESC);
-  OPT("-V --version      ", VERSIONDESC);
+  fprintf(stderr, "usage: %s\n", progname);
 }
 
 void main(int argc, char **argv) 
@@ -31,20 +26,21 @@ void main(int argc, char **argv)
   int fd, sc;
   struct kbkeycode a;
 
-  miscsetup();
+  progname = strip_path(argv[0]);
   
-  simple_options(argc, argv, usage);
+  if (argc != 1)
+      badusage("wrong number of args");
   
   if (-1 == (fd = get_console_fd(NULL)))
       exit (1);
   
-  printf(_("Plain scancodes xx (hex) versus keycodes (dec)\n"));
-  printf(_("0 is an error; for 1-88 (0x01-0x58) scancode equals keycode\n"));
+  printf("Plain scancodes xx (hex) versus keycodes (dec)\n");
+  printf("0 is an error; for 1-88 (0x01-0x58) scancode equals keycode\n");
   
   for(sc=88; sc<256; sc++) 
     {
       if (sc == 128)
-	  printf(_("\n\nEscaped scancodes e0 xx (hex)\n"));
+	  printf("\n\nEscaped scancodes e0 xx (hex)\n");
       if (sc % 8 == 0) 
 	{
 	  if (sc < 128)
@@ -68,7 +64,7 @@ void main(int argc, char **argv)
 	  else 
 	    {
 	      perror("KDGETKEYCODE");
-	      fprintf(stderr, _("failed to get keycode for scancode 0x%x\n"),
+	      fprintf(stderr, "failed to get keycode for scancode 0x%x\n",
 		      sc);
 	      exit(1);
 	    }
