@@ -1,45 +1,46 @@
 
 /*  A Bison parser, made from loadkeys.y
-    by GNU Bison version 1.28  */
+ by  GNU Bison version 1.25
+  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	EOL	257
-#define	NUMBER	258
-#define	LITERAL	259
-#define	CHARSET	260
-#define	KEYMAPS	261
-#define	KEYCODE	262
-#define	EQUALS	263
-#define	PLAIN	264
-#define	SHIFT	265
-#define	CONTROL	266
-#define	ALT	267
-#define	ALTGR	268
-#define	SHIFTL	269
-#define	SHIFTR	270
-#define	CTRLL	271
-#define	CTRLR	272
-#define	COMMA	273
-#define	DASH	274
-#define	STRING	275
-#define	STRLITERAL	276
-#define	COMPOSE	277
-#define	TO	278
-#define	CCHAR	279
-#define	ERROR	280
-#define	PLUS	281
-#define	UNUMBER	282
-#define	ALT_IS_META	283
-#define	STRINGS	284
-#define	AS	285
-#define	USUAL	286
-#define	ON	287
-#define	FOR	288
+#define	EOL	258
+#define	NUMBER	259
+#define	LITERAL	260
+#define	CHARSET	261
+#define	KEYMAPS	262
+#define	KEYCODE	263
+#define	EQUALS	264
+#define	PLAIN	265
+#define	SHIFT	266
+#define	CONTROL	267
+#define	ALT	268
+#define	ALTGR	269
+#define	SHIFTL	270
+#define	SHIFTR	271
+#define	CTRLL	272
+#define	CTRLR	273
+#define	COMMA	274
+#define	DASH	275
+#define	STRING	276
+#define	STRLITERAL	277
+#define	COMPOSE	278
+#define	TO	279
+#define	CCHAR	280
+#define	ERROR	281
+#define	PLUS	282
+#define	UNUMBER	283
+#define	ALT_IS_META	284
+#define	STRINGS	285
+#define	AS	286
+#define	USUAL	287
+#define	ON	288
+#define	FOR	289
 
 #line 62 "loadkeys.y"
 
-#include <lct/cline.h>
+#include <config.h>
 
 #include <errno.h>
 #include <stdio.h>
@@ -54,11 +55,12 @@
 #include <sysexits.h>
 #include <signal.h>
 
+#include <lct/local.h>
 #include <lct/utils.h>
 #include <lct/console.h>
+#include <lct/font.h>		/* findkeymap() */
 #include <lct/ksyms.h>
 #include <lct/modifiers.h>
-#include <lct/generic.h>
 
 int verbose;
 void lk_push(void);				  /* in analyze.c */
@@ -77,8 +79,9 @@ extern int line_nr, rvalct;
 extern struct kbsentry kbs_buf;
 extern FILE* yyin;
 
-/* give error message if using unicode compose strings? */
-int unicode_warning = 0;
+/* name to use in error messages */
+char *progname;
+
 /* What keymaps are we defining? */
 char defining[MAX_NR_KEYMAPS];
 char keymaps_line_seen = 0;
@@ -139,7 +142,7 @@ int private_error_ct = 0;
 #define	YYFLAG		-32768
 #define	YYNTBASE	35
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 288 ? yytranslate[x] : 54)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 289 ? yytranslate[x] : 54)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -167,10 +170,10 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
-     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
-    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
-    27,    28,    29,    30,    31,    32,    33,    34
+     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
+     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
+    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
+    26,    27,    28,    29,    30,    31,    32,    33,    34
 };
 
 #if YYDEBUG != 0
@@ -204,11 +207,11 @@ static const short yyrhs[] = {    -1,
 
 #if YYDEBUG != 0
 static const short yyrline[] = { 0,
-   149,   150,   152,   153,   154,   155,   156,   157,   158,   159,
-   160,   161,   163,   168,   173,   178,   182,   187,   192,   193,
-   195,   201,   206,   215,   219,   224,   225,   229,   234,   235,
-   237,   238,   239,   240,   241,   242,   243,   244,   246,   279,
-   280,   282,   289,   291,   293,   295,   297
+   151,   152,   154,   155,   156,   157,   158,   159,   160,   161,
+   162,   163,   165,   170,   175,   180,   184,   189,   194,   195,
+   197,   203,   208,   217,   221,   226,   227,   231,   236,   237,
+   239,   240,   241,   242,   243,   244,   245,   246,   248,   281,
+   282,   284,   291,   293,   295,   297,   299
 };
 #endif
 
@@ -303,8 +306,7 @@ static const short yycheck[] = {     3,
     62
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/share/misc/bison.simple"
-/* This file comes from bison-1.28.  */
+#line 3 "/usr/share/bison.simple"
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -321,67 +323,47 @@ static const short yycheck[] = {     3,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
+#ifndef alloca
+#ifdef __GNUC__
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
+#include <alloca.h>
+#else /* not sparc */
+#if defined (MSDOS) && !defined (__TURBOC__)
+#include <malloc.h>
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+#include <malloc.h>
+ #pragma alloca
+#else /* not MSDOS, __TURBOC__, or _AIX */
+#ifdef __hpux
+#ifdef __cplusplus
+extern "C" {
+void *alloca (unsigned int);
+};
+#else /* not __cplusplus */
+void *alloca ();
+#endif /* not __cplusplus */
+#endif /* __hpux */
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc.  */
+#endif /* not GNU C.  */
+#endif /* alloca not defined.  */
+
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
-#ifndef YYSTACK_USE_ALLOCA
-#ifdef alloca
-#define YYSTACK_USE_ALLOCA
-#else /* alloca not defined */
-#ifdef __GNUC__
-#define YYSTACK_USE_ALLOCA
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
-#define YYSTACK_USE_ALLOCA
-#include <alloca.h>
-#else /* not sparc */
-/* We think this test detects Watcom and Microsoft C.  */
-/* This used to test MSDOS, but that is a bad idea
-   since that symbol is in the user namespace.  */
-#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
-#if 0 /* No need for malloc.h, which pollutes the namespace;
-	 instead, just don't use alloca.  */
-#include <malloc.h>
-#endif
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-/* I don't know what this was needed for, but it pollutes the namespace.
-   So I turned it off.   rms, 2 May 1997.  */
-/* #include <malloc.h>  */
- #pragma alloca
-#define YYSTACK_USE_ALLOCA
-#else /* not MSDOS, or __TURBOC__, or _AIX */
-#if 0
-#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
-		 and on HPUX 10.  Eventually we can turn this on.  */
-#define YYSTACK_USE_ALLOCA
-#define alloca __builtin_alloca
-#endif /* __hpux */
-#endif
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc */
-#endif /* not GNU C */
-#endif /* alloca not defined */
-#endif /* YYSTACK_USE_ALLOCA not defined */
-
-#ifdef YYSTACK_USE_ALLOCA
-#define YYSTACK_ALLOC alloca
-#else
-#define YYSTACK_ALLOC malloc
-#endif
-
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -390,8 +372,8 @@ static const short yycheck[] = {     3,
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	goto yyacceptlab
-#define YYABORT 	goto yyabortlab
+#define YYACCEPT	return(0)
+#define YYABORT 	return(1)
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -472,12 +454,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-/* Define __yy_memcpy.  Note that the size argument
-   should be passed with type unsigned int, because that is what the non-GCC
-   definitions require.  With GCC, __builtin_memcpy takes an arg
-   of type size_t, but it can handle unsigned int.  */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+int yyparse (void);
+#endif
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -489,7 +471,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     unsigned int count;
+     int count;
 {
   register char *f = from;
   register char *t = to;
@@ -504,10 +486,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, unsigned int count)
+__yy_memcpy (char *to, char *from, int count)
 {
-  register char *t = to;
   register char *f = from;
+  register char *t = to;
   register int i = count;
 
   while (i-- > 0)
@@ -517,7 +499,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "/usr/share/misc/bison.simple"
+#line 196 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -538,15 +520,6 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-#ifdef YYPARSE_PARAM
-int yyparse (void *);
-#else
-int yyparse (void);
-#endif
-#endif
-
 int
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -575,7 +548,6 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
-  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -660,32 +632,18 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
-	  if (yyfree_stacks)
-	    {
-	      free (yyss);
-	      free (yyvs);
-#ifdef YYLSP_NEEDED
-	      free (yyls);
-#endif
-	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-#ifndef YYSTACK_USE_ALLOCA
-      yyfree_stacks = 1;
-#endif
-      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1,
-		   size * (unsigned int) sizeof (*yyssp));
-      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
-		   size * (unsigned int) sizeof (*yyvsp));
+      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
+      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1,
-		   size * (unsigned int) sizeof (*yylsp));
+      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -846,43 +804,43 @@ yyreduce:
   switch (yyn) {
 
 case 13:
-#line 164 "loadkeys.y"
+#line 166 "loadkeys.y"
 {
 			    set_charset(kbs_buf.kb_string);
 			;
     break;}
 case 14:
-#line 169 "loadkeys.y"
+#line 171 "loadkeys.y"
 {
 			    alt_is_meta = 1;
 			;
     break;}
 case 15:
-#line 174 "loadkeys.y"
+#line 176 "loadkeys.y"
 {
 			    strings_as_usual();
 			;
     break;}
 case 16:
-#line 179 "loadkeys.y"
+#line 181 "loadkeys.y"
 {
 			    compose_as_usual(kbs_buf.kb_string);
 			;
     break;}
 case 17:
-#line 183 "loadkeys.y"
+#line 185 "loadkeys.y"
 {
 			    compose_as_usual(0);
 			;
     break;}
 case 18:
-#line 188 "loadkeys.y"
+#line 190 "loadkeys.y"
 {
 			    keymaps_line_seen = 1;
 			;
     break;}
 case 21:
-#line 196 "loadkeys.y"
+#line 198 "loadkeys.y"
 {
 			    int i;
 			    for (i = yyvsp[-2]; i<= yyvsp[0]; i++)
@@ -890,13 +848,13 @@ case 21:
 			;
     break;}
 case 22:
-#line 202 "loadkeys.y"
+#line 204 "loadkeys.y"
 {
 			    addmap(yyvsp[0],1);
 			;
     break;}
 case 23:
-#line 207 "loadkeys.y"
+#line 209 "loadkeys.y"
 {
 			    if (KTYP(yyvsp[-3]) != KT_FN)
 				lkfatal1("'%s' is not a function key symbol",
@@ -906,67 +864,67 @@ case 23:
 			;
     break;}
 case 24:
-#line 216 "loadkeys.y"
+#line 218 "loadkeys.y"
 {
 			    compose(yyvsp[-4], yyvsp[-3], yyvsp[-1]);
 			;
     break;}
 case 25:
-#line 220 "loadkeys.y"
+#line 222 "loadkeys.y"
 {
 			    compose(yyvsp[-4], yyvsp[-3], yyvsp[-1]);
 			;
     break;}
 case 26:
-#line 224 "loadkeys.y"
+#line 226 "loadkeys.y"
 { mod = 0; ;
     break;}
 case 27:
-#line 226 "loadkeys.y"
+#line 228 "loadkeys.y"
 {
 			    addkey(yyvsp[-3], mod, yyvsp[-1]);
 			;
     break;}
 case 28:
-#line 230 "loadkeys.y"
+#line 232 "loadkeys.y"
 {
 			    addkey(yyvsp[-2], 0, yyvsp[0]);
 			;
     break;}
 case 31:
-#line 237 "loadkeys.y"
+#line 239 "loadkeys.y"
 { mod |= M_SHIFT;	;
     break;}
 case 32:
-#line 238 "loadkeys.y"
+#line 240 "loadkeys.y"
 { mod |= M_CTRL;	;
     break;}
 case 33:
-#line 239 "loadkeys.y"
+#line 241 "loadkeys.y"
 { mod |= M_ALT;		;
     break;}
 case 34:
-#line 240 "loadkeys.y"
+#line 242 "loadkeys.y"
 { mod |= M_ALTGR;	;
     break;}
 case 35:
-#line 241 "loadkeys.y"
+#line 243 "loadkeys.y"
 { mod |= M_SHIFTL;	;
     break;}
 case 36:
-#line 242 "loadkeys.y"
+#line 244 "loadkeys.y"
 { mod |= M_SHIFTR;	;
     break;}
 case 37:
-#line 243 "loadkeys.y"
+#line 245 "loadkeys.y"
 { mod |= M_CTRLL;	;
     break;}
 case 38:
-#line 244 "loadkeys.y"
+#line 246 "loadkeys.y"
 { mod |= M_CTRLR;	;
     break;}
 case 39:
-#line 247 "loadkeys.y"
+#line 249 "loadkeys.y"
 {
 	    int i, j;
 
@@ -999,36 +957,36 @@ case 39:
 	;
     break;}
 case 42:
-#line 283 "loadkeys.y"
+#line 285 "loadkeys.y"
 {
 			    if (rvalct >= MAX_NR_KEYMAPS)
-				lkfatal(_("too many keydefinitions on one line"));
+				lkfatal("too many keydefinitions on one line");
 			    key_buf[rvalct++] = yyvsp[0];
 			;
     break;}
 case 43:
-#line 290 "loadkeys.y"
+#line 292 "loadkeys.y"
 {yyval=yyvsp[0];;
     break;}
 case 44:
-#line 292 "loadkeys.y"
+#line 294 "loadkeys.y"
 {yyval=(yyvsp[0] ^ 0xf000); unicode_used=1;;
     break;}
 case 45:
-#line 294 "loadkeys.y"
+#line 296 "loadkeys.y"
 {yyval=K(KT_LETTER, KVAL(yyvsp[0]));;
     break;}
 case 46:
-#line 296 "loadkeys.y"
+#line 298 "loadkeys.y"
 {yyval=yyvsp[0];;
     break;}
 case 47:
-#line 298 "loadkeys.y"
+#line 300 "loadkeys.y"
 {yyval=K(KT_LETTER, KVAL(yyvsp[0]));;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "/usr/share/misc/bison.simple"
+#line 498 "/usr/share/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1223,48 +1181,28 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
-
- yyacceptlab:
-  /* YYACCEPT comes here.  */
-  if (yyfree_stacks)
-    {
-      free (yyss);
-      free (yyvs);
-#ifdef YYLSP_NEEDED
-      free (yyls);
-#endif
-    }
-  return 0;
-
- yyabortlab:
-  /* YYABORT comes here.  */
-  if (yyfree_stacks)
-    {
-      free (yyss);
-      free (yyvs);
-#ifdef YYLSP_NEEDED
-      free (yyls);
-#endif
-    }
-  return 1;
 }
-#line 300 "loadkeys.y"
+#line 302 "loadkeys.y"
 			
 
 void usage()
 {
-  printf(_("Usage: %s [option...] [mapfile...]\n"), progname);
-  OPTIONS_ARE();
-  OPT("-c --clearcompose ", _("clear kernel compose table"));
-  OPT("-d --default      ", _("load default keymap file")); /* FIXME: should print DEFKMAP */
-  OPT("-m --mktable      ", _("output a \"defkeymap.c\" to stdout"));
-  OPT("-s --clearstrings ", _("clear kernel string table"));
-  OPT("-q --quiet        ", _("be silent"));
-  OPT("-v --verbose      ", _("report the changes"));
-  OPT("-v --verbose      ", _("report more changes"));
-
-  OPT("-h --help         ", HELPDESC);
-  OPT("-V --version      ", VERSIONDESC);
+  version();
+  
+  fprintf(stderr, 
+	  "Usage: %s [option...] [mapfile...]\n"
+	  "\n"
+	  "valid options are:\n"
+	  "\n"
+	  "        -c --clearcompose clear kernel compose table\n"
+          "        -d --default      load \"%s\" \n"
+          "        -h --help         display this help text\n"
+          "        -m --mktable      output a \"defkeymap.c\" to stdout\n"
+          "        -s --clearstrings clear kernel string table\n"
+          "        -q --quiet        be silent\n"
+          "        -v --verbose      report the changes\n"
+          "        -v --verbose      report more changes\n",
+	  progname, DEFKMAP);
 }
 
 char **args;
@@ -1276,7 +1214,7 @@ int nocompose = 0;
 
 int main(int argc, char *argv[])
 {
-  const char *short_opts = "cdhmsqvV";
+  const char *short_opts = "cdhmsqv";
   const struct option long_opts[] = {
     { "clearcompose", no_argument, NULL, 'c' },
     { "default",    no_argument, NULL, 'd' },
@@ -1285,13 +1223,12 @@ int main(int argc, char *argv[])
     { "clearstrings", no_argument, NULL, 's' },
     { "quiet",	no_argument, NULL, 'q' },
     { "verbose",    no_argument, NULL, 'v' },
-    { "version", no_argument, NULL, 'V' },
     { NULL, 0, NULL, 0 }
   };
   int c;
   sigset_t sigset, old_sigset;
   
-  miscsetup();
+  progname = strip_path(argv[0]);
 
   while ((c = getopt_long(argc, argv,
 			  short_opts, long_opts, NULL)) != EOF)
@@ -1316,9 +1253,6 @@ int main(int argc, char *argv[])
 	case 'v':
 	  verbose++;
 	  break;
-	case 'V':
-	  version();
-	  exit(0);
 	case 'h':
 	  usage();
 	  exit (0);
@@ -1337,9 +1271,9 @@ int main(int argc, char *argv[])
   sigprocmask (SIG_BLOCK, &sigset, &old_sigset);
   if (yyparse() || private_error_ct)
     {
-      fprintf(stderr, _("syntax error in map file\n"));
+      fprintf(stderr, "syntax error in map file\n");
       if(!optm)
-	fprintf(stderr, _("key bindings not changed\n"));
+	fprintf(stderr, "key bindings not changed\n");
       exit(1);
     }
   /* restore mask */
@@ -1427,7 +1361,7 @@ int yywrap(void)
     if((f = findkeymap(DEFKMAP, pathname, sizeof(pathname), stdin, NULL)) == NULL)
       {
 	perror("findkeymap");
-	fprintf(stderr, _("Cannot find %s\n"), DEFKMAP);
+	fprintf(stderr, "Cannot find %s\n", DEFKMAP);
 	exit(1);
       }
     goto gotf;
@@ -1444,7 +1378,7 @@ int yywrap(void)
   else if ((f = findkeymap(*args, pathname, sizeof(pathname), stdin, NULL)) == NULL)
     {
       perror("findkeymap");
-      fprintf(stderr, _("cannot open file %s\n"), *args);
+      fprintf(stderr, "cannot open file %s\n", *args);
       exit(1);
     }
   /*
@@ -1469,12 +1403,12 @@ gotf:
 static void addmap(int i, int explicit)
 {
   if (i < 0 || i >= MAX_NR_KEYMAPS)
-    lkfatal0(_("addmap called with bad index %d"), i);
+    lkfatal0("addmap called with bad index %d", i);
   
   if (!defining[i])
     {
       if (keymaps_line_seen && !explicit)
-	lkfatal0(_("adding map %d violates explicit keymaps line)"), i);
+	lkfatal0("adding map %d violates explicit keymaps line", i);
       
       defining[i] = 1;
       if (max_keymap <= i)
@@ -1488,9 +1422,9 @@ static void killkey(int index, int table)
   /* roughly: addkey(index, table, K_HOLE); */
 
   if (index < 0 || index >= NR_KEYS)
-    lkfatal0(_("killkey called with bad index %d"), index);
+    lkfatal0("killkey called with bad index %d", index);
   if (table < 0 || table >= MAX_NR_KEYMAPS)
-    lkfatal0(_("killkey called with bad table %d"), table);
+    lkfatal0("killkey called with bad table %d", table);
   if (key_map[table])
     (key_map[table])[index] = K_HOLE;
   if (keymap_was_set[table])
@@ -1504,9 +1438,9 @@ static void addkey(int index, int table, int keycode)
   if (keycode == -1)
     return;
   if (index < 0 || index >= NR_KEYS)
-    lkfatal0(_("addkey called with bad index %d"), index);
+    lkfatal0("addkey called with bad index %d", index);
   if (table < 0 || table >= MAX_NR_KEYMAPS)
-    lkfatal0(_("addkey called with bad table %d"), table);
+    lkfatal0("addkey called with bad table %d", table);
 
   if (!defining[table])
     addmap(table, 0);
@@ -1550,7 +1484,7 @@ static void addfunc(struct kbsentry kbs)
 
   if (kbs.kb_func >= MAX_NR_FUNC)
     {
-      fprintf(stderr, _("%s: addfunc called with bad func %d\n"),
+      fprintf(stderr, "%s: addfunc called with bad func %d\n",
 	      progname, kbs.kb_func);
       exit(1);
     }
@@ -1573,7 +1507,7 @@ static void addfunc(struct kbsentry kbs)
   sh = strlen(kbs.kb_string) + 1;
   if (fp + sh > func_buf + sizeof(func_buf))
     {
-      fprintf(stderr, _("%s: addfunc: func_buf overflow\n"), progname);
+      fprintf(stderr, "%s: addfunc: func_buf overflow\n", progname);
       exit(1);
     }
   q = fp;
@@ -1587,37 +1521,18 @@ static void addfunc(struct kbsentry kbs)
       func_table[i] += sh;
 }
 
-static int unicode_problem(void)
-{
-  /* Return TRUE if this kernel cannot handle unicode compose chars
-   *  properly;
-   * (Currently struct kbdiacr has 3 chars: { base, diacr, result},
-   * But result needs to be a string for proper Unicode handling)
-   */
-  return 1;
-}
-     
 static void compose(int diacr, int base, int res)
 {
   struct kbdiacr *p;
   if (accent_table_size == MAX_DIACR)
     {
-      fprintf(stderr, _("compose table overflow\n"));
+      fprintf(stderr, "compose table overflow\n");
       exit(1);
     }
   p = &accent_table[accent_table_size++];
   p->diacr = diacr;
   p->base = base;
   p->result = res;
-  if (unicode_problem() && res > 0xFF) {
-    fprintf(stderr,
-	    _("Warning: Compose char %4x ('%c','%c') > 0xFF will be truncated to %2x\n"),
-	    res, p->base, p->diacr, p->result);
-    if (!unicode_warning) {
-      fprintf(stderr,_("  (Linux kernel < 2.3.X can't handle unicode compose chars properly)\n"));
-      unicode_warning = 1;
-    }
-  }
 }
 
 static int defkeys(int fd)
@@ -1654,7 +1569,7 @@ static int defkeys(int fd)
 		    {
 		      if (errno == EPERM)
 			{
-			  fprintf(stderr, _("Keymap %d: Permission denied\n"), i);
+			  fprintf(stderr, "Keymap %d: Permission denied\n", i);
 			  j = NR_KEYS;
 			  continue;
 			}
@@ -1663,10 +1578,10 @@ static int defkeys(int fd)
 		  else
 		    ct++;
 		  if(verbose)
-		    printf(_("keycode %d, table %d = %d%s\n"), j, i,
-			   (key_map[i])[j], fail ? _("    FAILED") : "");
+		    printf("keycode %d, table %d = %d%s\n", j, i,
+			   (key_map[i])[j], fail ? "    FAILED" : "");
 		  else if (fail)
-		    fprintf(stderr, _("failed to bind key %d to value %d\n"),
+		    fprintf(stderr, "failed to bind key %d to value %d\n",
 			    j, (key_map[i])[j]);
 		}
 	    }
@@ -1679,7 +1594,7 @@ static int defkeys(int fd)
 	  ke.kb_value = K_NOSUCHMAP;
 
 	  if (verbose > 1)
-	    printf(_("deallocate keymap %d\n"), i);
+	    printf("deallocate keymap %d\n", i);
 
 	  if(ioctl(fd, KDSKBENT, (unsigned long)&ke))
 	    {
@@ -1687,7 +1602,7 @@ static int defkeys(int fd)
 		{
 		  perror("KDSKBENT");
 		  fprintf(stderr,
-			  _("%s: could not deallocate keymap %d\n"),
+			  "%s: could not deallocate keymap %d\n",
 			  progname, i);
 		  exit(1);
 		}
@@ -1704,7 +1619,7 @@ static int defkeys(int fd)
 			break; /* old kernel */
 		      perror("KDSKBENT");
 		      fprintf(stderr,
-			      _("%s: cannot deallocate or clear keymap\n"),
+			      "%s: cannot deallocate or clear keymap\n",
 			      progname);
 		      exit(1);
 		    }
@@ -1717,11 +1632,11 @@ static int defkeys(int fd)
     {
       if (ioctl(fd, KDSKBMODE, oldm))
 	{
-	  fprintf(stderr, _("%s: failed to restore keyboard mode\n"),
+	  fprintf(stderr, "%s: failed to restore keyboard mode\n",
 		  progname);
 	}
-      fprintf(stderr, _("%s: warning: this map uses Unicode symbols\n"
-	      "    (perhaps you want to do `kbd_mode -u'?)\n"),
+      fprintf(stderr, "%s: warning: this map uses Unicode symbols\n"
+	      "    (perhaps you want to do `kbd_mode -u'?)\n",
 	      progname);
     }
   return ct;
@@ -1768,7 +1683,7 @@ static int deffuncs(int fd)
 	{
 	  strcpy(kbs_buf.kb_string, p);
 	  if (ioctl(fd, KDSKBSENT, (unsigned long)&kbs_buf))
-	    fprintf(stderr, _("failed to bind string '%s' to function %s\n"),
+	    fprintf(stderr, "failed to bind string '%s' to function %s\n",
 		    ostr(kbs_buf.kb_string), syms[KT_FN].table[kbs_buf.kb_func]);
 	  else
 	    ct++;
@@ -1777,7 +1692,7 @@ static int deffuncs(int fd)
 	{
 	  kbs_buf.kb_string[0] = 0;
 	  if (ioctl(fd, KDSKBSENT, (unsigned long)&kbs_buf))
-	    fprintf(stderr, _("failed to clear string %s\n"),
+	    fprintf(stderr, "failed to clear string %s\n",
 		    syms[KT_FN].table[kbs_buf.kb_func]);
 	  else
 	    ct++;
@@ -1795,14 +1710,14 @@ static int defdiacs(int fd)
   if (kd.kb_cnt > MAX_DIACR) 
     {
       kd.kb_cnt = MAX_DIACR;
-      fprintf(stderr, _("too many compose definitions\n"));
+      fprintf(stderr, "too many compose definitions\n");
     }
   for (i = 0; i < kd.kb_cnt; i++)
       kd.kbdiacr[i] = accent_table[i];
   
   if(ioctl(fd, KDSKBDIACR, (unsigned long) &kd)) 
     {
-      fprintf(stderr, _("KDSKBDIACR failed\n"));
+      fprintf(stderr, "KDSKBDIACR failed\n");
       perror("");
       exit(1);
     }
@@ -1863,7 +1778,7 @@ static void do_constant (void)
 	{
 	  u_short key;
 	  if (!key_map[r0])
-	    lkfatal(_("impossible error in do_constant"));
+	    lkfatal("impossible error in do_constant");
 	  key = (key_map[r0])[i];
 	  do_constant_key (i, key);
 	}
@@ -1884,19 +1799,14 @@ static void loadkeys (void)
     diacct = defdiacs(fd);
   if (verbose)
     {
-      char* nbuf = NULL;
-      unsigned nbufsize = 0;
-      
-      printf(_("\nChanged %s and %s.\n"),
-	       LCT_NUMBER(nbuf, nbufsize, keyct, "key", "keys"),
-	       LCT_NUMBER(nbuf, nbufsize, funcct, "string", "strings"));
+      printf("\nChanged %d key%s and %d string%s.\n",
+	     keyct, (keyct == 1) ? "" : "s",
+	     funcct, (funcct == 1) ? "" : "s");
       if (accent_table_size > 0 || nocompose)
-	printf(_("Loaded %s.\n"),
-	       LCT_NUMBER(nbuf, nbufsize, diacct,
-		      "compose definition",
-		      "compose definitions"));
+	printf("Loaded %d compose definition%s.\n",
+	       diacct, (diacct == 1) ? "" : "s");
       else
-	printf(_("(No change in compose definitions.)\n"));
+	printf("(No change in compose definitions.)\n");
     }
 }
 
@@ -1933,7 +1843,7 @@ static void compose_as_usual(char *charset)
 {
   if (charset && strcmp(charset, "iso-8859-1"))
     {
-      fprintf(stderr, _("loadkeys: don't know how to compose for %s\n"),
+      fprintf(stderr, "loadkeys: don't know how to compose for %s\n",
 	      charset);
       exit(1);
     }
