@@ -4,7 +4,6 @@
  * Version 0.92
  */
 
-#include <config.h>
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -21,7 +20,7 @@ void saveunicodemap(int fd, char *oufil, int verbose, int no_act)
   get_kernel_unimap(fd, &descr);
   
   if (no_act)
-      printf(_("Would save %d SFM entries in `%s'.\n"), descr.entry_ct, oufil);
+      printf("Would save %d SFM entries in `%s'.\n", descr.entry_ct, oufil);
   else
     {
       if (verbose)
