@@ -1,9 +1,6 @@
-#include <config.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-
-#include <lct/local.h>
 #include <lct/utils.h>
 
 /* from kbd 0.96 */
@@ -12,7 +9,7 @@ void* xmalloc(size_t n)
   void *p = malloc(n);
   if (p == NULL)
     {
-      fprintf(stderr, _("Out of Memory\n"));
+      fprintf(stderr, "Out of Memory\n");
       exit(1);
     }
   return p;
@@ -23,7 +20,7 @@ char* xstrdup(char *p)
   char *q = strdup(p);
   if (q == NULL)
     {
-      fprintf(stderr, _("Out of Memory?\n"));
+      fprintf(stderr, "Out of Memory?\n");
       exit(1);
     }
   return q;
