@@ -8,7 +8,7 @@
  * font positions, and the second [-u] giving the correspondence between
  * font positions and Unicode values.
  */
-#include <lct/cline.h>
+#include <config.h>
 
 #include <stdio.h>
 #include <unistd.h>
@@ -25,61 +25,59 @@
 #include <sys/ioctl.h>
 #include <linux/kd.h>
 
+#include <lct/local.h>
 #include <lct/console.h>
 #include <lct/font.h>
-#include <lct/generic.h>
 
 #define DEFUNIMAP DATADIR "/" TRANSDIR "/def"
 
-const int DEFAULT_FFF = FFF_PSF;
-
 int verbose = 0;
 int no_act = 0;
 
+char *progname;
 char pathname[1024];
 
 static int saveoldfont(int fd, char *outfile, int as_psf, int with_unimap);
-static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
-			char* ifil,		  /* input font-file name, or "" for default */
-			int requested_height,	  /*  */
-			struct unimapdesc* ud,	  /* output parameter for sfm if any */
-			int no_u);		  /* 1 <=> do not load a unimap here
-						   * even if one is in the file */
+void loadnewfont(int fd,	       /* FD of the console for ioctl() */
+		 char* ifil,	       /* input font-file name, or "" for default */
+		 int iunit,	       /*  */
+		 struct unimapdesc* ud,/* output parameter for sfm if any */
+		 int no_u); 	       /* 1 <=> do not load a unimap here [used for PSF] */
 
 static void usage()
 {
   version();
-  printf(_("Usage:  %s [options] [commands]\n"), progname);
-  OPTIONS_ARE();
-  OPT("-v --verbose        ", _("List operations as they are done"));
-  OPT("-n --no-act         ", _("Do not change the console state nor write to any file"));
-  OPT("-H --char-height=N  ", _("(N in 0..32) Choose the right font from a codepage that\n"
-				 "contains three fonts (only 8/14/16 allowed then), or choose\n"
-				 "default font, ie. \"default8xN\""));
-  OPT("--force-no-sfm      ", _("Suppress loading of a screen-font map [use with care]"));
-  OPT("-1 --g1             ", _("When loading an ACM, activate G1 charset instead of G0"));
-  OPT("--tty=device        ", _("Use `device' as console device for ioctls"));
-
-  COMMANDS_ARE();
-  OPT("-f --font=file      ", _("Load the console-font from specified file"));
-  OPT("-d --default-font   ", _("Load a default font from a file"));
-  OPT("-R --rom-font       ", _("Restore ROM font (does not work with all kernels)"));
-  OPT("-u --sfm --screen-font-map=file", "");
-  OPT("                    ", _("Load the SFM from specified file\n"
-				 "(instead of the one in font-file, if any)"));
-  OPT("-k --sfm-fallback=file  ", _("Merge SFM fallbacks from file into SFM"));
-  OPT("-m --acm --app-charset-map=file  ", _("Load the ACM from specified file"));
-  OPT("-F --old-font=file  ", _("Write current font to prefered format (now: psf-with-sfm)"));
-/*    OPT("--old-font-psf=file ", _("Write current font to PSF file before loading a new one")); */
-/*    OPT("--old-font-raw=file ", _("Write current font to RAW file before loading a new one")); */
-  OPT("   --font-format=.. ", _("Select font file format for saving"));
-  OPT("   --list-font-formats", "");
-  OPT("                    ", _("List font file formats available to libcfont"));
-  OPT("-M --old-acm=file   ", _("Write current ACM to file before loading a new one"));
-  OPT("-U --old-sfm=file   ", _("Write current SFM to file before loading a new one"));
-
-  OPT("-h --help           ", HELPDESC);
-  OPT("-V --version        ", VERSIONDESC);
+  fprintf(stderr,
+	  "Usage:  %s [options] [commands]\n"
+	  "\nOptions:\n"
+	  " -h --help           This help screen\n"
+	  " -v --verbose        List operations as they are done.\n"
+	  " -V --version        Show version.\n"
+	  " -n --no-act         Do not change the console state nor write to any file.\n"
+	  " -H --char-height=N  (N in 0..32) Choose the right font from a codepage that\n"
+	  "                     contains three fonts (only 8/14/16 allowed then), or choose\n"
+	  "                     default font, ie. \"default8xN\".\n"
+	  " --force-no-sfm      Suppress loading of a screen-font map [use with care].\n"
+	  " -1 --g1             When loading an ACM, activate G1 charset instead of G0.\n"
+	  " --tty=device        Use `device' as console device for ioctls.\n"
+	  "\nCommands:\n"
+	  " -f --font=file      Load the console-font from specified file.\n"
+	  " -d --default-font   Load a default font.\n"
+	  " -u --sfm --screen-font-map=file\n"
+	  "                     Load the SFM from specified file\n"
+	  "                     (instead of the one in font-file, if any).\n"
+	  " -k --sfm-fallback=file\n"
+	  "                     Merge SFM fallbacks from file into SFM.\n"
+	  " -m --acm --app-charset-map=file\n"
+	  "                     Load the ACM from specified file.\n"
+	  " -F --old-font=file  Write current font to prefered format (now: psf-with-sfm).\n"
+	  " --old-font-psf=file Write current font to PSF file before loading a new one.\n"
+	  " --old-font-psf-with-sfm=file\n"
+	  "                     Same as -old-font-psf, and add current SFM in the PSF file.\n"
+	  " --old-font-raw=file Write current font to RAW file before loading a new one.\n"
+	  " -M --old-acm=file   Write current ACM to file before loading a new one.\n"
+	  " -U --old-sfm=file   Write current SFM to file before loading a new one.\n"
+	  "\n", progname);
 }
 
 static inline void CHECK_STD(char* file, int* stdfile)
@@ -87,7 +85,7 @@ static inline void CHECK_STD(char* file, int* stdfile)
   if (!strcmp(file, "-"))
     {
       if (*stdfile)
-	  badusage(_("too many `-' as filenames"));
+	  badusage("too many `-' as filenames");
       else
 	  *stdfile = 1;
     }
@@ -95,87 +93,80 @@ static inline void CHECK_STD(char* file, int* stdfile)
 
 #define OPT_or 128
 #define OPT_op 129
-#define OPT_ops 130
-#define OPT_no_sfm 131
-#define OPT_tty 132
-#define OPT_fff 133
-#define OPT_fff_list 134
+#define OPT_no_sfm 130
+#define OPT_tty 131
 
 const struct option opts[] = 
 {
   /* operations */
-  {"help", no_argument, 0, 'h'},
-  {"version", no_argument, 0, 'V'},
-  {"verbose", no_argument, 0, 'v'},
-  {"tty", required_argument, 0, OPT_tty},
-  {"g1", no_argument, 0, '1'},
+    {"help", no_argument, 0, 'h'},
+    {"version", no_argument, 0, 'V'},
+    {"verbose", no_argument, 0, 'v'},
+    {"tty", required_argument, 0, OPT_tty},
+    {"g1", no_argument, 0, '1'},
   
-  {"char-height", required_argument, 0, 'H'},
-  {"no-act", no_argument, 0, 'n'},
+    {"char-height", required_argument, 0, 'H'},
+    {"no-act", no_argument, 0, 'n'},
 
-  {"font", required_argument, 0, 'f'},
-  {"old-font", required_argument, 0, 'F'},
+    {"font", required_argument, 0, 'f'},
+    {"old-font", required_argument, 0, 'F'},
   
-  {"default-font", no_argument, 0, 'd'},
-  {"rom-font", no_argument, 0, 'R'},
+    {"default-font", no_argument, 0, 'd'},
 
   /* default old-font is synonym for old-font-psf-with-sfm */
   /* this may change when better formats are supported */
-  {"old-font-psf", required_argument, 0, OPT_op},
-  {"old-font-raw", required_argument, 0, OPT_or},
-  {"font-format", required_argument, 0, OPT_fff},
-  {"list-font-formats", no_argument, 0, OPT_fff_list},
-
-  {"screen-font-map", required_argument, 0, 'u'},
-  {"sfm", required_argument, 0, 'u'},
-  {"app-charset-map", required_argument, 0, 'm'},
-  {"acm", required_argument, 0, 'm'},
-
-  {"force-no-sfm", no_argument, 0, OPT_no_sfm},
+    {"old-font-psf-with-sfm", required_argument, 0, 'F'},
+    {"old-font-psf", required_argument, 0, OPT_op},
+    {"old-font-raw", required_argument, 0, OPT_or},
   
-  {"old-sfm", required_argument, 0, 'U'},
-  {"old-acm", required_argument, 0, 'M'},
+    {"screen-font-map", required_argument, 0, 'u'},
+    {"sfm", required_argument, 0, 'u'},
+    {"app-charset-map", required_argument, 0, 'm'},
+    {"acm", required_argument, 0, 'm'},
+
+    {"force-no-sfm", no_argument, 0, OPT_no_sfm},
   
-  {"sfm-fallback", required_argument, 0, 'k'},
+    {"old-sfm", required_argument, 0, 'U'},
+    {"old-acm", required_argument, 0, 'M'},
+  
+    {"sfm-fallback", required_argument, 0, 'k'},
   
   /* end marker */
-  {0, 0, 0, 0}
+    {0, 0, 0, 0}
 };
 
 /* const for default-font handling - loadnewfont() wants it to be empty */
 char* default_font = "";
-char* rom_font = (char*)(-1);
 
 void main(int argc, char *argv[])
 {
-  char *ifil, *mfil, *ufil, *ofil, *omfil, *oufil, **fallback_files;
+  char *ifil, *mfil, *ufil, *orfil, *opfil, *omfil, *oufil, *opufil, **fallback_files;
   int nb_fallback_files = 0;
   int fd = 0;
   int requested_height, no_u;
   int stdin_taken, stdout_taken;
   char* tty_name = NULL;	       /* optional name of a tty for the console */
   int g_set = 0;		       /* G0 or G1 */
-  int old_font_format = FF_UNKNOWN;
   
   struct unimapdesc ud;
   
   int result;			       /* option handling */
   int an_option;
 
-  ifil = mfil = ufil = omfil = oufil = ofil = NULL;
+  ifil = mfil = ufil = orfil = opfil = omfil = oufil = opufil = NULL;
   fallback_files = NULL;
   requested_height = 0;
   stdin_taken = stdout_taken = 0;      /* 1 means respective FILE is already used for file I/O */
   no_u = 0;			       /* 1 means ignore map inside file */
 
-  miscsetup();
-  
+  progname = strip_path(argv[0]);
+
   while (1)
     {
-      result = getopt_long(argc, argv, "Vhvn1H:f:F:dRu:m:U:M:k:", opts, &an_option);
+      result = getopt_long(argc, argv, "Vhvn1H:f:F:du:m:U:M:k:", opts, &an_option);
 
       if (result == EOF)
-	break;
+	  break;
       
       switch (result)
 	{
@@ -202,47 +193,41 @@ void main(int argc, char *argv[])
 	  /* numeric height */
 	  requested_height = atoi(optarg);
 	  if(requested_height <= 0 || requested_height > 32)
-	    badusage(_("--char-height argument should be in 1..31"));
+	      badusage("--char-height argument should be in 1..31");
 	  break;
 
 	case 'f':
 	  if (ifil)
-	    badusage(_("only one font file is allowed"));
+	      badusage("only one font file is allowed");
 	  ifil = optarg;
 	  CHECK_STD(ifil, &stdin_taken);
 	  break;
 
 	case 'd':
 	  if (ifil)
-	    badusage(_("only one font file is allowed"));
+	      badusage("only one font file is allowed");
 	  ifil = default_font;
 	  break;
 	  
-	case 'R':
-	  if (ifil)
-	    badusage(_("only one font file is allowed"));
-	  ifil = rom_font;
-	  break;
-	  
 	case 'm':
 	  if (mfil)
-	    badusage(_("only one ACM is allowed"));
+	      badusage("only one ACM is allowed");
 	  mfil = optarg;
 	  CHECK_STD(mfil, &stdin_taken);
 	  break;
 
 	case 'u':
 	  if (ufil)
-	    badusage(_("only one SFM is allowed"));
+	      badusage("only one SFM is allowed");
 	  if (no_u)
-	    badusage(_("multiple requests for SFM handling"));
+	      badusage("multiple requests for SFM handling");
 	  ufil = optarg;
 	  CHECK_STD(ufil, &stdin_taken);
 	  no_u = 1;
 	  break;
 	  
 	case OPT_no_sfm:
-	  fprintf (stderr, _("WARNING: not using a unimap may lead to erroneous display !\n"));
+	  fprintf (stderr, "WARNING: not using a unimap may lead to erroneous display !\n");
 	  no_u = 1;
 	  break;
 	  
@@ -252,7 +237,7 @@ void main(int argc, char *argv[])
 	      (fallback_files = (char**)realloc (fallback_files,
 						 (nb_fallback_files + 1) * sizeof (char*))))
 	    {
-	      perror (_("realloc fallback_files"));
+	      perror ("realloc fallback_files");
 	      exit (EX_OSERR);
 	    }
 	  fallback_files[nb_fallback_files] = optarg;
@@ -260,59 +245,36 @@ void main(int argc, char *argv[])
 	  break;
 	  
 	case OPT_or:
-	  if (ofil)
-	    badusage (_("only one output font file is allowed"));
-	  ofil = optarg;
-	  old_font_format = FFF_RAW;
-	  CHECK_STD(ofil, &stdout_taken);
+	  if (orfil)
+	      badusage("only one output RAW font-file is allowed");
+	  orfil = optarg;
+	  CHECK_STD(orfil, &stdout_taken);
 	  break;
 	  
 	case OPT_op:
-	  if (ofil)
-	    badusage (_("only one output font file is allowed"));
-	  ofil = optarg;
-	  old_font_format = FFF_PSF;
-	  CHECK_STD(ofil, &stdout_taken);
-	  break;
-
-	case 'F':
-	  if (ofil)
-	    badusage (_("only one output font file is allowed"));
-	  ofil = optarg;
-	  CHECK_STD(ofil, &stdout_taken);
-	  break;
-
-	case OPT_fff:
-	  {
-	    int tmp_fff;
-
-	    if (ofil && (old_font_format != FF_UNKNOWN))
-	      badusage (_("only one output font file is allowed"));
-
-	    tmp_fff = fff_name_to_id (optarg);
-	    if (tmp_fff == FF_UNKNOWN)
-	      badusage (_("unknown font format"));
-	    
-	    old_font_format = tmp_fff;
-	  }
-	  break;
-
-	case OPT_fff_list:
-	  printf (_("Available file formats:\n\n"));
-	  fff_fprintf_names (stdout, "\t%s\n");
-	  exit(0);
+	  if (opfil)
+	      badusage("only one output PSF font-file is allowed");
+	  opfil = optarg;
+	  CHECK_STD(opfil, &stdout_taken);
 	  break;
 	  
+	case 'F':
+	  if (opufil)
+	      badusage("only one output PSF+SFM font-file is allowed");
+	  opufil = optarg;
+	  CHECK_STD(opufil, &stdout_taken);
+	  break;
+
 	case 'M':
 	  if (omfil)
-	    badusage(_("only one output ACM file is allowed"));
+	      badusage("only one output ACM file is allowed");
 	  omfil = optarg;
 	  CHECK_STD(omfil, &stdout_taken);
 	  break;
 	  
 	case 'U':
 	  if (oufil)
-	    badusage(_("only one output SFM file is allowed"));
+	      badusage("only one output SFM file is allowed");
 	  oufil = optarg;
 	  CHECK_STD(oufil, &stdout_taken);
 	  break;
@@ -323,15 +285,15 @@ void main(int argc, char *argv[])
 	  break;
 	  
 	default:
-	  badusage(_("unknown option"));
+	  badusage("unknown option");
 	}
     }
 
   if (optind < argc)
-    badusage (_("no non-option arguments are valid"));
+      badusage ("no non-option arguments are valid");
 
-  if (!ifil && !mfil && !ufil && !ofil && !omfil && !oufil && !fallback_files)
-    badusage(_("nothing to do"));
+  if (!ifil && !mfil && !ufil && !orfil && !opfil && !omfil && !oufil && !opufil && !fallback_files)
+      badusage("nothing to do");
 
   if (-1 == (fd = get_console_fd(tty_name)))
     {
@@ -343,37 +305,31 @@ void main(int argc, char *argv[])
    * save current state
    */
   
-  if (ofil)
-    {
-      if (old_font_format == FFF_RAW)
-	{
-	  if (saveoldfont(fd, ofil, 0, 0))
-	    perror (_("Saving raw old font")), exit(1);
-	}
+  if (orfil)
+      if (saveoldfont(fd, orfil, 0, 0))
+	  perror ("Saving raw old font"), exit(1);
 
-      else if (old_font_format == FFF_PSF)
-	{
-	  if (saveoldfont(fd, ofil, 1, 1))
-	    perror (_("Saving PSF old font")), exit(1);
-	}
+  if (opfil)
+      if (saveoldfont(fd, opfil, 1, 0))
+	  perror ("Saving PSF old font"), exit(1);
+
+  if (opufil)
+      if (saveoldfont(fd, opufil, 1, 1))
+	  perror ("Saving PSF+unimap old font"), exit(1);
 
-      else
-	fprintf (stderr, _("Cannot save font using this file format.\n")), exit(1);
-    }
-  
   if (omfil)
     {
       if (no_act)
-	fprintf (stderr, _("Would save ACM to file `%s'.\n"), omfil);
+	   fprintf (stderr, "Would save ACM to file `%s'.\n", omfil);
       else
 	{
-	  if (verbose) fprintf (stderr, _("Saving ACM to file `%s'.\n"), omfil);
-	  acm_save (fd, omfil);
+	  if (verbose) fprintf (stderr, "Saving ACM to file `%s'.\n", omfil);
+	  saveoldmap(fd, omfil);
 	}
     }
   
   if (oufil)
-    sfm_save (fd, oufil, verbose, no_act);
+      saveunicodemap(fd, oufil, verbose, no_act);
   
   /*
    * set new state
@@ -385,19 +341,19 @@ void main(int argc, char *argv[])
       char pathname[1024];
       
       if ((f = findacm(mfil, pathname, sizeof(pathname), stdin, NULL)) == NULL)
-	perror("findacm"), exit(1);
+	  perror("findacm"), exit(1);
       
 
       if (no_act)
-	printf(_("Would load ACM from `%s'\n"), pathname);
+	  printf("Would load ACM from `%s'\n", pathname);
       else
 	{
-	  if (verbose) printf(_("Loading ACM from `%s'\n"), pathname);
+	  if (verbose) printf("Loading ACM from `%s'\n", pathname);
 	  
-	  if (-1 == acm_load(fd, f))
-	    fprintf (stderr, _("Error reading ACM file.\n"));
+	  if (-1 == screen_map_load(fd, f))
+	    fprintf (stderr, "Error reading ACM file.\n");
 	  else
-	    if (acm_activate(fd, g_set))
+	    if (acm_activate(g_set))
 	      perror ("acm_activate"), exit (EX_UNAVAILABLE);
 	}
     }
@@ -405,12 +361,7 @@ void main(int argc, char *argv[])
   /* load a font and get a unimap if any */
   ud.entry_ct = 0;
   if (ifil)
-    {
-      if (ifil == rom_font)
-	restore_rom_font(fd);
-      else
-	loadnewfont(fd, ifil, requested_height, &ud, no_u);
-    }
+      loadnewfont(fd, ifil, requested_height, &ud, no_u);
   
   if (ufil)
     {
@@ -418,15 +369,15 @@ void main(int argc, char *argv[])
       FILE* mapf;
       
       if (NULL == (mapf = findsfm(ufil, pathname, sizeof(pathname), stdin, NULL)))
-	perror("findsfm"), exit (1);
+	  perror("findsfm"), exit (1);
       
       if (no_act)
-	fprintf (stderr, _("Would read screen-font map from %s.\n"), pathname);
+	  fprintf (stderr, "Would read screen-font map from %s.\n", pathname);
       else if (verbose)
-	fprintf (stderr, _("Reading screen-font map from %s.\n"), pathname);
+	  fprintf (stderr, "Reading screen-font map from %s.\n", pathname);
 
       if (sfm_read_ascii (mapf, &ud, 512))
-	perror ("sfm_read_ascii"), exit (EX_DATAERR);
+	  perror ("sfm_read_ascii"), exit (EX_DATAERR);
     }
   
   if (fallback_files)
@@ -437,13 +388,13 @@ void main(int argc, char *argv[])
        * get the current one so we can merge fallbacks in */
       if (!ud.entry_ct)
 	{
-	  if (verbose) fprintf (stderr, _("Requesting SFM from kernel.\n"));
-	  if (-1 == get_kernel_sfm(fd, &ud))
+	  if (verbose) fprintf (stderr, "Requesting SFM from kernel.\n");
+	  if (-1 == get_kernel_unimap(fd, &ud))
 	    {
 	      if (errno == ENXIO)
-		fprintf(stderr, _("No valid SFM currently loaded. Aborting.\n"));
+		fprintf(stderr, "No valid SFM currently loaded. Aborting.\n");
 	      else
-		perror ("get_kernel_sfm");
+		perror ("get_kernel_unimap");
 	      exit (1);
 	    }
 	}
@@ -475,7 +426,7 @@ void main(int argc, char *argv[])
 		perror ("findsfmfallback"), exit (1);
 	  
 	      if (verbose)
-		fprintf (stderr, _("Reading SFM fallbacks from `%s'.\n"), fullname);
+		fprintf (stderr, "Reading SFM fallbacks from `%s'.\n", fullname);
 	  
 	      sfmfb = NULL;
 	      if (-1 == sfm_fallback_read (fbfile, &sfmfb, &sfmfb_ct))
@@ -483,7 +434,7 @@ void main(int argc, char *argv[])
 
 #ifndef NDEBUG
 	      if (verbose)
-		fprintf (stderr, _("Read %u fallback entries.\n"), sfmfb_ct);
+		fprintf (stderr, "Read %u fallback entries.\n", sfmfb_ct);
 #endif
 	      assert (sfmfb_ct > 0);
 	      
@@ -508,19 +459,19 @@ void main(int argc, char *argv[])
 	  memcpy (&ud, &new_ud, sizeof(struct unimapdesc));
 	}
       else
-	fprintf (stderr, _("WARNING: No SFM found in file or kernel ?  Ignoring fallback file.\n"));
+	  fprintf (stderr, "WARNING: No SFM found in file or kernel ?  Ignoring fallback file.\n");
     }
 	
   
   if (ud.entry_ct)
     {
       if (no_act)
-	fprintf (stderr, _("Would set kernel SFM.\n"));
+	  fprintf (stderr, "Would set kernel SFM.\n");
       else
 	{
-	  if (verbose) fprintf (stderr, _("Setting kernel SFM.\n"));
-	  if (set_kernel_sfm (fd, &ud))
-	    perror ("set_kernel_sfm"), exit (EX_OSERR);
+	  if (verbose) fprintf (stderr, "Setting kernel SFM.\n");
+	  if (set_kernel_unimap (fd, &ud))
+	      perror ("set_kernel_unimap"), exit (EX_OSERR);
 	}
     }
   
@@ -528,81 +479,11 @@ void main(int argc, char *argv[])
 }
 
 
-simple_font* read_font (FILE* fontfile, int font_format, int requested_height)
-{
-  if (fff_is_simple_font (font_format))
-    {
-      simple_font* font = read_simple_font (fontfile, font_format);
-	
-      if (requested_height && (requested_height != font->font.charheight))
-	{
-	  free_simple_font (font);
-	  errno = EINVAL;
-	  return NULL;
-	}
-	
-      return font;
-    }
-
-  else if (fff_is_font_group (font_format))
-    {
-      font_group* fontgroup = read_font_group (fontfile, font_format);
-      simple_font* font;
-      int index;
-
-      /* if only one font in group, do not require it on command-line */
-      if ((requested_height == 0) && (fontgroup->fontcount == 1))
-	requested_height = fontgroup->fontcount;
-
-#if 1
-      fprintf (stderr, "Group has %d fonts:", fontgroup->fontcount);
-      for (index=0; index<fontgroup->fontcount; index++)
-	fprintf (stderr, " %d", fontgroup->fonts[index].charheight);
-      fprintf (stderr, "\n");
-#endif
-	
-      /* find requested_height in group */
-      for (index=0; index<fontgroup->fontcount; index++)
-	if (fontgroup->fonts[index].charheight == requested_height)
-	  break;
-
-      if (requested_height == 0)
-	{
-	  fprintf (stderr, "No font height specified\n");
-	  errno = EINVAL;
-	  return NULL;
-	}
-
-      if (index==fontgroup->fontcount)
-	{
-	  errno = EINVAL;
-	  return NULL; /* height not in file */
-	}
-
-      font = (simple_font*)calloc (1, sizeof(simple_font));
-      if (!font) return NULL;
-
-      memcpy (&font->sfm, &fontgroup->sfm, sizeof (struct unimapdesc));
-      memcpy (&font->font, &fontgroup->fonts[index], sizeof (struct cfontdesc));
-
-      free_font_group (fontgroup);
-      return font;
-    }
-  
-  else
-    {
-      errno = EINVAL;
-      return NULL;
-    }
-}
-
-
-static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
-			char* ifil,		  /* input font-file name, or "" for default */
-			int requested_height,	  /*  */
-			struct unimapdesc* ud,	  /* output parameter for sfm if any */
-			int no_u)		  /* 1 <=> do not load a unimap here
-						   * even if one is in the file */
+void loadnewfont(int fd,	       /* FD of the console for ioctl() */
+		 char* ifil,	       /* input font-file name, or "" for default */
+		 int requested_height,	       /*  */
+		 struct unimapdesc* ud,/* output parameter for sfm if any */
+		 int no_u) 	       /* 1 <=> do not load a unimap here [used for PSF] */
 {
   FILE *fpi;
   char defname[20];
@@ -620,7 +501,7 @@ static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
    * If yes, open it & set its name for further processing.
    */
   
-  if (ifil[0] == '\0')
+  if (!*ifil)			       /* ie. if (ifil == "") */
     {
       /* try to find some default file */
       
@@ -633,7 +514,7 @@ static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
 	      (fpi = findfont("default8x14", pathname, sizeof(pathname), NULL, &font_magic)) == NULL &&
 	      (fpi = findfont("default8x08", pathname, sizeof(pathname), NULL, &font_magic)) == NULL) 
 	    {
-	      fprintf(stderr, _("Cannot find a default font file.\n"));
+	      fprintf(stderr, "Cannot find a default font file.\n");
 	      exit(1);
 	    }
 	}
@@ -642,7 +523,7 @@ static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
 	  sprintf(defname, "default8x%02d", requested_height);
 	  if ((fpi = findfont(defname, pathname, sizeof(pathname), NULL, &font_magic)) == NULL) 
 	    {
-	      fprintf(stderr, _("Cannot find default font file `default8x%02d'.\n"), requested_height);
+	      fprintf(stderr, "Cannot find default font file `default8x%02d'.\n", requested_height);
 	      exit(1);
 	    }
 	}
@@ -652,7 +533,7 @@ static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
       if ((fpi = findfont(ifil, pathname, sizeof(pathname), stdin, &font_magic)) == NULL)
 	{
 	  perror ("findfont");
-	  fprintf (stderr, _("Cannot open font file `%s'.\n"), ifil);
+	  fprintf (stderr, "Cannot open font file `%s'.\n", ifil);
 	  exit(1);
 	}
     }
@@ -668,11 +549,11 @@ static void loadnewfont(int fd,			  /* FD of the console for ioctl() */
     }
 
   /* FIXME: use result */
-  the_font = read_font (fpi, font_magic, requested_height);
+  the_font = read_simple_font (fpi, NULL, font_magic);
 
   if (!the_font)
     {
-      perror ("read_font()");
+      perror ("read_simple_font()");
       exit (1);
     }
   
@@ -686,10 +567,10 @@ fprintf (stderr, "WARNING: Not using a unimap may lead to erroneous display !\n"
    */
 
   /* Check that font-size is valid */
-#if !defined( PIO_FONTX )
+#if !defined( PIO_FONTX ) || defined( sparc )
   if (the_font->font.charcount != 256) 
     {
-      fprintf(stderr, _("Only fontsize 256 supported.\n"));
+      fprintf(stderr, "Only fontsize 256 supported.\n");
       exit(1);
     }
 #endif
@@ -700,14 +581,14 @@ fprintf (stderr, "WARNING: Not using a unimap may lead to erroneous display !\n"
    */
 #warning check pathname validity
   if (no_act)
-    fprintf(stderr, _("Would load %d-chars %dx%d font from file `%s'.\n"),
+    fprintf(stderr, "Would load %d-chars %dx%d font from file `%s'.\n",
 	    the_font->font.charcount,
 	    the_font->font.charwidth, the_font->font.charheight,
 	    pathname);
   else
     {
       if (verbose)
-	fprintf(stderr, _("Loading %d-chars %dx%d font from file `%s'.\n"),
+	fprintf(stderr, "Loading %d-chars %dx%d font from file `%s'.\n",
 		the_font->font.charcount,
 		the_font->font.charwidth, the_font->font.charheight,
 		pathname);
@@ -733,7 +614,7 @@ fprintf (stderr, "WARNING: Not using a unimap may lead to erroneous display !\n"
       if (NULL == (mapf = findsfm(DEFUNIMAP, pathname, sizeof(pathname), NULL, NULL)))
 	perror("findsfm"), exit (1);
       
-      if (verbose) fprintf (stderr, _("Reading default SFM from `%s'.\n"), pathname);
+      if (verbose) fprintf (stderr, "Reading default SFM from `%s'.\n", pathname);
 
       sfm_read_ascii (mapf, ud, 512);
       
@@ -754,7 +635,7 @@ static int saveoldfont(int fd, char *outfile, int as_psf, int with_unimap)
   /* invocation check */
   if (with_unimap && !as_psf)
     {
-      fprintf(stderr, _("Cannot write SFM into non-PSF font-file.\n"));
+      fprintf(stderr, "Cannot write SFM into non-PSF font-file.\n");
       errno = EINVAL;
       return -1;
     }
@@ -764,9 +645,8 @@ static int saveoldfont(int fd, char *outfile, int as_psf, int with_unimap)
   
   if (cfd->charwidth != 8)
     {
-      fprintf (stderr, 
-	       _("Can only save 8bit-wide fonts for now,"
-	       " and font is %d-bit wide.\n"), cfd->charwidth);
+      fprintf (stderr, "Can only save 8bit-wide fonts for now,"
+	       " and font is %d-bit wide.\n", cfd->charwidth);
       errno = EBFONT;		       /* FIXME: should be something else ? */
       return -1;
     }
@@ -774,20 +654,19 @@ static int saveoldfont(int fd, char *outfile, int as_psf, int with_unimap)
   /* RAW files can only have 256 chars */
   if (!as_psf && (cfd->charcount != 256))
     {
-      fprintf (stderr, 
-	       _("Can only save 256-chars fonts in RAW files,"
-		 " and font has %d chars.\n"), cfd->charcount);
+      fprintf (stderr, "Can only save 256-chars fonts in RAW files,"
+	       " and font has %d chars.\n", cfd->charcount);
       errno = EBFONT;		       /* FIXME: should be something else ? */
       return -1;
     }
   
   if (cfd->charheight == 0)
-      fprintf(stderr, _("Found nothing to save.\n"));
+      fprintf(stderr, "Found nothing to save.\n");
   else 
     {
       /* get unimap if requested */
       if (with_unimap)
-	  if (-1 == get_kernel_sfm (fd, &descr))
+	  if (-1 == get_kernel_unimap (fd, &descr))
 	      with_unimap = 0;	       /* no valid unimap */
 
       if (!no_act)
@@ -813,12 +692,12 @@ static int saveoldfont(int fd, char *outfile, int as_psf, int with_unimap)
       if (verbose)
 	  fprintf(stderr, 
 		  no_act 
-		  ? _("Would have saved 8x%d %s font file on `%s'%s.\n")
-		  : _("Saved 8x%d %s font file on `%s'%s.\n"), 
+		  ? "Would have saved 8x%d %s font file on `%s'%s.\n"
+		  : "Saved 8x%d %s font file on `%s'%s.\n", 
 		  cfd->charheight,
 		  as_psf ? "PSF" : "RAW",
 		  outfile,
-		  as_psf ? ( with_unimap ? _(", with SFM") : _(", without SFM")) : "");
+		  as_psf ? ( with_unimap ? ", with SFM" : ", without SFM") : "");
 
     }
 
