@@ -69,8 +69,6 @@
  * data.
  */
 
-#include <lct/cline.h>
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -87,15 +85,16 @@
 #endif
 #include <linux/vt.h>
 
-#include <getopt.h>
-
+#include <lct/local.h>
 #include <lct/utils.h>
 #include <lct/console.h>
-#include <lct/generic.h>
+#include <lct/font.h>				  /* findvideomode() */
 
 #define MODE_RESTORETEXTMODE	0
 #define MODE_VGALINES		1
 
+static char* progname;
+
 /* VGA textmode register tweaking. */
 static void vga_init_io();
 static void vga_400_scanlines();
@@ -105,128 +104,45 @@ static int vga_get_fontheight();
 static void vga_set_cursor( int, int );
 static void vga_set_verticaldisplayend_lowbyte( int );
 
-static void usage() 
+void usage() 
 {
-  printf(_("Usage:  %s COLSxROWS\n"
-	   "        %s COLS ROWS\n"
-	   "        %s -lines ROWS, with ROWS one of 25, 28, 30, 34, 36, 40, 44, 50, 60\n"), 
+  fprintf(stderr,
+	  "Usage:  %s COLSxROWS\n"
+	  "        %s COLS ROWS\n"
+	  "        %s -lines ROWS, with ROWS one of 25, 28, 30, 34, 36, 40, 44, 50, 60\n", 
 	  progname, progname, progname);
 }
 
-static void parse_cmdline (int argc, char **argv, 
-		    int *mode, int *rows, int *cols)
-{
-  int c;
-  char *p; 
-  const struct option long_opts[] =
-  {
-    { "cols", 1, NULL, 'c' },
-    { "lines", 1, NULL, 'l'},
-    { "rows", 1, NULL, 'r'},
-    { "help", no_argument, NULL, 'h' },
-    { "version", no_argument, NULL, 'v' },
-    { NULL, 0, NULL, 0 }
-  };
-
-  while ( (c = getopt_long (argc, argv, "-vhc:r:l:", long_opts, NULL)) != EOF)
-    {
-      switch (c)
-	{
-	case 'h':
-	  usage();
-	  exit(0);
-	case 'v':
-	  version();
-	  exit(0);
-	case 'c':
-	  *cols = atoi(optarg);
-	  if (*cols == 0)
-	    {
-	      fprintf(stderr, _("%s: Invalid number of columns: %s\n"),
-		      progname, optarg);
-	      exit(1);
-	    }
-	  break;
-	case 'r':
-	  *rows = atoi(optarg);
-	  if (*rows == 0)
-	    {
-	      fprintf(stderr,_("%s: Invalid number of rows: %s\n"),
-		      progname, optarg);
-	      exit(1);
-	    }
-	  break;
-	case 'l':			/* lines */
-	  *rows = atoi(optarg);
-	  *mode = MODE_VGALINES;
-	  break;
-	case '?':
-	  usage();
-	  exit(1);
-	}
-  }
-
-   
-  if (argc == optind +1) /* COLSxROWS case */
-    {
-      if (*rows || *cols)
-	{
-	  fprintf(stderr,_("%s: Invalid arguments"),
-		  progname);
-	  exit(1);
-	}
-      if ((p = index (argv[optind],'x')) != 0)
-	{
-	  *cols = atoi (argv[optind]);
-	  *rows = atoi (p+1);
-	  return;
-	}
-      else
-	{
-	  fprintf(stderr,_("%s: Unrecognized argument"),
-		  progname);
-	  exit(1);
-	}
-      return;
-     
-    }
-   
-  if (argc == optind +2) /* COLS ROWS case */
-    {
-      if (*rows || *cols)
-	{
-	  fprintf(stderr,_("%s: Invalid arguments"),
-		  progname);
-	  exit(1);
-	}
-      *cols = atoi(argv[optind]);
-      *rows = atoi(argv[optind+1]);
-      return;
-    }
-       
-  if (argc == optind && *rows && *cols)
-    return;
-   
-  fprintf (stderr, _("%s: bad number of arguments\n"),
-	   progname);
-  exit(1);
-}
-  
-
 int main(int argc, char* argv[]) 
 {
-  int rr = 0, cc = 0, fd, i, mode = MODE_RESTORETEXTMODE;
+  int rr, cc, fd, i, mode;
   struct vt_sizes vtsizes;
   struct vt_stat vtstat;
   struct winsize winsize;
+  char *p;
   char tty[12], cmd[80], infile[1024];
   FILE *fin;
   char *defaultfont;
   char pathname[1024];
-
-  miscsetup();
   
-  parse_cmdline (argc, argv, &mode, &rr, &cc);
+  progname = strip_path(argv[0]);
+  
+  if (argc < 2)
+      badusage("not enough arguments");
+  rr = 0;			/* make gcc happy */
+  cc = atoi(argv[1]);
+  mode = MODE_RESTORETEXTMODE;
+  if (argc == 3 && strcmp(argv[1], "-lines") == 0) 
+    {
+      mode = MODE_VGALINES;
+      rr = atoi(argv[2]);
+    }
+  else if (argc == 2 && (p = index(argv[1], 'x')) != 0)
+      rr = atoi(p+1);
+  else if(argc == 3)
+      rr = atoi(argv[2]);
+  else
+      badusage("unrecognized argument");
   
   if (mode == MODE_RESTORETEXTMODE) 
     {
@@ -235,7 +151,7 @@ int main(int argc, char* argv[])
       fin = findvideomode(infile, pathname, sizeof(pathname), stdin, NULL);
       if (!fin) 
 	{
-	  fprintf(stderr, _("%s: cannot find videomode file %s\n"), progname, infile);
+	  fprintf(stderr, "%s: cannot find videomode file %s\n", progname, infile);
 	  exit(EX_NOINPUT);
 	}
       fclose(fin);
@@ -256,7 +172,7 @@ int main(int argc, char* argv[])
       if (rr != 25 && rr != 28 && rr !=30 && rr != 34 && rr != 36
 	  && rr != 40 && rr != 44 && rr != 50 && rr != 60) 
 	{
-	  fprintf(stderr, _("Invalid number of lines\n"));
+	  fprintf(stderr, "Invalid number of lines\n");
 	  exit(EX_DATAERR);
 	}
     }
@@ -334,9 +250,9 @@ int main(int argc, char* argv[])
        * there is a annoying changing partial line at the bottom.
        */
       vga_set_verticaldisplayend_lowbyte((fontheight * rr - 1) & 0xff);
-      printf(_("Old mode: %dx%d  New mode: %dx%d\n"), winsize.ws_col,
+      printf("Old mode: %dx%d  New mode: %dx%d\n", winsize.ws_col,
 	     winsize.ws_row, cc, rr);
-      printf(_("Old #scanlines: %d  New #scanlines: %d  Character height: %d\n"),
+      printf("Old #scanlines: %d  New #scanlines: %d  Character height: %d\n",
 	     scanlines_old, scanlines_new, fontheight);
     }
 
@@ -349,7 +265,7 @@ int main(int argc, char* argv[])
 	{
 	  if(errno)
 	      perror("restoretextmode");
-	  fprintf(stderr, _("%s: the command `%s' failed\n"), progname, cmd);
+	  fprintf(stderr, "%s: the command `%s' failed\n", progname, cmd);
 	  exit(1);
 	}
     }
@@ -359,6 +275,7 @@ int main(int argc, char* argv[])
    * do
    *     stty rows $rr cols $cc < $i
    * done
+   * kill -SIGWINCH `cat /tmp/selection.pid`
    */
   winsize.ws_row = rr;
   winsize.ws_col = cc;
@@ -374,6 +291,22 @@ int main(int argc, char* argv[])
 	     }
 	 }
 
+  /* Try to tell selection about the change */
+  if ((fd = open("/tmp/selection.pid", 0)) >= 0) 
+    {
+      char buf[64];
+      int n = read(fd, buf, sizeof(buf));
+      if (n > 0) 
+	{
+	  int pid;
+	  
+	  buf[n-1] = 0;
+	  pid = atoi(buf);
+	  kill(pid, SIGWINCH);
+	}
+      close(fd);
+    }
+
   /* do: setfont default8x16 */
   /* (other people might wish other fonts - this should be settable) */
   
@@ -399,16 +332,16 @@ int main(int argc, char* argv[])
     {
       if(errno)
 	  perror("setfont");
-      fprintf(stderr, _("%s: the command `%s' failed\n"), progname, cmd);
+      fprintf(stderr, "%s: the command `%s' failed\n", progname, cmd);
       exit(1);
     }
 
   fprintf(stderr,
-	  _("%s: don't forget to change TERM (maybe to con%dx%d or linux-%dx%d)\n"),
+	  "%s: don't forget to change TERM (maybe to con%dx%d or linux-%dx%d)\n",
 	  progname, cc, rr, cc, rr);
   if (getenv("LINES") || getenv("COLUMNS"))
       fprintf(stderr,
-	      _("Also the variables LINES and COLUMNS may need adjusting.\n"));
+	      "Also the variables LINES and COLUMNS may need adjusting.\n");
   
   return 0;
 }
@@ -445,7 +378,7 @@ static void vga_init_io()
 {
   if (iopl(3) < 0) 
     {
-      fprintf(stderr, _("%s: cannot get I/O permissions.\n"), progname);
+      fprintf(stderr, "%s: cannot get I/O permissions.\n", progname);
       exit(1);
     }
   crtcport = 0x3d4;
