@@ -4,8 +4,6 @@
  * Show time in upper right hand corner of the console screen
  * aeb, 951202, following a suggestion by Miguel de Icaza.
  */
-#include <lct/cline.h>
-
 #include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -16,18 +14,6 @@
 # include <time.h>
 #endif
 
-#include <lct/utils.h>
-
-static void usage()
-{
-  printf(_("Usage: %s\n"
-	   "Show time in upper right hand corner of the console screen\n"), progname);
-  OPTIONS_ARE();
-
-  OPT("-h --help         ", HELPDESC);
-  OPT("-V --version      ", VERSIONDESC);
-}
-
 void
 fatal(char *s) {
     perror(s);
@@ -48,18 +34,13 @@ number_of_columns() {
 }
 
 int
-main(int argc, char **argv)
-{
+main(){
     int fd;
     int cols = number_of_columns();
     time_t tid;
     struct tm *t;
     char tijd[10];
 
-    miscsetup();
-  
-    simple_options (argc, argv, usage);
-
     if((fd = open("/dev/vcs", O_WRONLY)) < 0)
 	fatal("/dev/vcs");
 
